==> openwebmail-2.21.tgz: cgi-bin/openwebmail/userstat.pl <==
#!/usr/bin/perl
#
# userstat.pl - a mail status javascript generator for static html page
#
# 2003/10/08 tung.AT.turtle.ee.ncku.edu.tw
#
# This script is designed to be used by static html pages to
# display openwebmail user mail/calendar status dynamically.
# All you need to do is to include the following block in html source code.
#
# <table cellspacing=0 cellpadding=0><tr><td>
# <script language="JavaScript"
# src="http://you_server_domainname/cgi-bin/openwebmail/userstat.pl">
# </script>
# </td></tr></table>
#
use strict;
use CGI qw(-private_tempfiles :standard);

# where to find the openwebmail scripts
my $ow_cgidir="/usr/local/www/cgi-bin/openwebmail";
my $ow_cgiurl="/cgi-bin/openwebmail";

# play newmail sound if cgi param playsound==1
my $soundurl="/openwebmail/sounds/YouGotMail.English.wav";

# status text to be displayed
my %text = (
   has_newmail   => "_USER_ has new mail",
   has_mail      => "_USER_ has mail",
   has_newevent  => "_USER_ has new event",
   has_event     => "_USER_ has event",
   user_calendar => "_USER_'s calendar"
);

################### No configuration required from here ###################

if (!defined($ENV{'GATEWAY_INTERFACE'})) {	# cmd mode
   print qq|\nThis script is designed to be used by static html pages to\n|.
         qq|display openwebmail user mail/calendar status dynamically.\n|.
         qq|All you need to do is to include the following block in html source code.\n\n|.
         qq|<table cellspacing=0 cellpadding=0><tr><td>\n|.
         qq|<script language="JavaScript"\n|.
         qq|src="http://you_server_domainname/cgi-bin/openwebmail/userstat.pl">\n|.
         qq|</script>\n|.
         qq|</td></tr></table>\n\n|;
   exit 1;
}

my $user = cookie('openwebmail-loginname') || param('loginname');
my $playsound = param('playsound');
my $html=qq|<a href="_URL_" target="_blank" style="text-decoration: none">|.
         qq|<font color="_COLOR_">_TEXT_</font></a>|;

if ($user ne "") {
   my $status=`$ow_cgidir/openwebmail-tool.pl -m -e $user`;
   if ($status =~ /has no mail/) {
      $html=~s|_URL_|$ow_cgiurl/openwebmail.pl?action=calmonth|;
      if ($status =~ /has new event/) {
         $html=~s|_COLOR_|#cc0000|;
         $html=~s|_TEXT_|$text{'has_newevent'}|;
      } elsif ($status =~ /has event/) {
         $html=~s|_COLOR_|#000000|;
         $html=~s|_TEXT_|$text{'has_event'}|;
      } else {
         $html=~s|_COLOR_|#000000|;
         $html=~s|_TEXT_|$text{'user_calendar'}|;
      }
   } else {
      $html=~s|_URL_|$ow_cgiurl/openwebmail.pl|;
      if ($status =~ /has new mail/) {
         $html=~s|_COLOR_|#cc0000|;
         $html=~s|_TEXT_|$text{'has_newmail'}|;
         if ($playsound) {
            $html.=qq|<embed src="$soundurl" autostart=true hidden=true>|;
         }
      } elsif ($status =~ /has mail/) {
         $html=~s|_COLOR_|#000000|;
         $html=~s|_TEXT_|$text{'has_mail'}|;
      }
   }
   $html=~s/_USER_/$user/g;
   $html=~s/'/\\'/g;

   print qq|Pragma: no-cache\n|.
         qq|Cache-control: no-cache,no-store\n|.
         qq|Content-Type: application/x-javascript\n\n|.
         qq|document.write('$html');\n|;
} else {
   print qq|Pragma: no-cache\n|.
         qq|Cache-control: no-cache,no-store\n|.
         qq|Content-Type: application/x-javascript\n\n|.
         qq|//\n|;
}

==> openwebmail-2.30.tgz: cgi-bin/openwebmail/userstat.pl <==
#!/usr/bin/perl
#
# userstat.pl - a mail status javascript generator for static html page
#
# 2003/10/08 tung.AT.turtle.ee.ncku.edu.tw
#
# This script is designed to be used by static html pages to
# display openwebmail user mail/calendar status dynamically.
# All you need to do is to include the following block in html source code.
#
# <table cellspacing=0 cellpadding=0><tr><td>
# <script language="JavaScript"
# src="http://you_server_domainname/cgi-bin/openwebmail/userstat.pl">
# </script>
# </td></tr></table>
#
use strict;
use CGI qw(-private_tempfiles :standard);

# where to find the openwebmail scripts
my $ow_cgidir="/usr/local/www/cgi-bin/openwebmail";
my $ow_cgiurl="/cgi-bin/openwebmail";

# play newmail sound if cgi param playsound==1
my $soundurl="/openwebmail/sounds/YouGotMail.English.wav";

# status text to be displayed
my %text = (
   has_newmail   => "_USER_ has new mail",
   has_mail      => "_USER_ has mail",
   has_newevent  => "_USER_ has new event",
   has_event     => "_USER_ has event",
   user_calendar => "_USER_'s calendar"
);

########## No configuration required from here ###################

if (!defined($ENV{'GATEWAY_INTERFACE'})) {	# cmd mode
   print qq|\nThis script is designed to be used by static html pages to\n|.
         qq|display openwebmail user mail/calendar status dynamically.\n|.
         qq|All you need to do is to include the following block in html source code.\n\n|.
         qq|<table cellspacing=0 cellpadding=0><tr><td>\n|.
         qq|<script language="JavaScript"\n|.
         qq|src="http://you_server_domainname/cgi-bin/openwebmail/userstat.pl">\n|.
         qq|</script>\n|.
         qq|</td></tr></table>\n\n|;
   exit 1;
}

my $user = cookie('openwebmail-loginname') || param('loginname') || '';
my $playsound = param('playsound')||'';
my $html=qq|<a href="_URL_" target="_blank" style="text-decoration: none">|.
         qq|<font color="_COLOR_">_TEXT_</font></a>|;

if ($user ne "") {
   my $status=`$ow_cgidir/openwebmail-tool.pl -m -e $user`;
   if ($status =~ /has no mail/) {
      $html=~s|_URL_|$ow_cgiurl/openwebmail.pl?action=calmonth|;
      if ($status =~ /has new event/) {
         $html=~s|_COLOR_|#cc0000|;
         $html=~s|_TEXT_|$text{'has_newevent'}|;
      } elsif ($status =~ /has event/) {
         $html=~s|_COLOR_|#000000|;
         $html=~s|_TEXT_|$text{'has_event'}|;
      } else {
         $html=~s|_COLOR_|#000000|;
         $html=~s|_TEXT_|$text{'user_calendar'}|;
      }
   } else {
      $html=~s|_URL_|$ow_cgiurl/openwebmail.pl|;
      if ($status =~ /has new mail/) {
         $html=~s|_COLOR_|#cc0000|;
         $html=~s|_TEXT_|$text{'has_newmail'}|;
         if ($playsound) {
            $html.=qq|<embed src="$soundurl" autostart=true hidden=true>|;
         }
      } elsif ($status =~ /has mail/) {
         $html=~s|_COLOR_|#000000|;
         $html=~s|_TEXT_|$text{'has_mail'}|;
      }
   }
   $html=~s/_USER_/$user/g;
   $html=~s/'/\\'/g;

   print qq|Pragma: no-cache\n|.
         qq|Cache-control: no-cache,no-store\n|.
         qq|Content-Type: application/x-javascript\n\n|.
         qq|document.write('$html');\n|;
} else {
   print qq|Pragma: no-cache\n|.
         qq|Cache-control: no-cache,no-store\n|.
         qq|Content-Type: application/x-javascript\n\n|.
         qq|//\n|;
}
